<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Time splitting method that generates predictions one month after the analysable start.
 *
 * @package   core_analytics
 * @copyright 2019 David Monllao {@link http://www.davidmonllao.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace core\analytics\time_splitting;

defined('MOODLE_INTERNAL') || die();

/**
 * Time splitting method that generates predictions one month after the analysable start.
 *
 * @package   core_analytics
 * @copyright 2019 David Monllao {@link http://www.davidmonllao.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class one_month_after_start extends \core_analytics\local\time_splitting\after_start {

    /**
     * The time splitting method name.
     *
     * @return \lang_string
     */
    public static function get_name(): \lang_string {
        return new \lang_string('timesplitting:onemonthafterstart');
    }

    /**
     * The period we should wait until we generate predictions for this.
     *
     * @param  \core_analytics\analysable $analysable Not used in this implementation.
     * @return \DateInterval
     */
    protected function wait_period(\core_analytics\analysable $analysable) {
        return new \DateInterval('P1M');
    }
}
